@@ -30,3 +30,11 @@ class Metadata(TypedDict):
     search_name: str
     plugin_id: int
     plugin_version_id: int
+
+
+class Update(TypedDict):
+    id: int
+    title: str
+    description: str
+    date: int
+    likes: int
